==> kubernetes-model-node-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/node/v1alpha1/OverheadBuilder.java <==
package io.fabric8.kubernetes.api.model.node.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OverheadBuilder extends io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluentImpl<io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead,io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadBuilder>{
  public OverheadBuilder() {
    this(false);
  }
  public OverheadBuilder(java.lang.Boolean validationEnabled) {
    this(new Overhead(), validationEnabled);
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluent<?> fluent) {
    this(fluent, false);
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Overhead(), validationEnabled);
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead instance) {
    this(fluent, instance, false);
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPodFixed(instance.getPodFixed()); 
    this.validationEnabled = validationEnabled; 
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead instance) {
    this(instance,false);
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPodFixed(instance.getPodFixed()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead build() {
    Overhead buildable = new Overhead(fluent.getPodFixed());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OverheadBuilder that = (OverheadBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-node-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/node/v1alpha1/OverheadBuilder.java <==
package io.fabric8.kubernetes.api.model.node.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OverheadBuilder extends io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluentImpl<io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead,io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadBuilder>{
  public OverheadBuilder() {
    this(false);
  }
  public OverheadBuilder(java.lang.Boolean validationEnabled) {
    this(new Overhead(), validationEnabled);
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluent<?> fluent) {
    this(fluent, false);
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Overhead(), validationEnabled);
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead instance) {
    this(fluent, instance, false);
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPodFixed(instance.getPodFixed()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead instance) {
    this(instance,false);
  }
  public OverheadBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPodFixed(instance.getPodFixed()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.node.v1alpha1.OverheadFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.node.v1alpha1.Overhead build() {
    Overhead buildable = new Overhead(fluent.getPodFixed());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OverheadBuilder that = (OverheadBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
